@@ -3,7 +3,7 @@ BEGIN {
   $Promises::Deferred::AUTHORITY = 'cpan:STEVAN';
 }
 {
-  $Promises::Deferred::VERSION = '0.01';
+  $Promises::Deferred::VERSION = '0.02';
 }
 # ABSTRACT: An implementation of Promises in Perl
 
@@ -37,6 +37,18 @@ sub promise { (shift)->{'promise'} }
 sub status  { (shift)->{'status'}  }
 sub result  { (shift)->{'result'}  }
 
+# predicates for all the status possiblities
+sub is_in_progress { (shift)->{'status'} eq IN_PROGRESS }
+sub is_resolving   { (shift)->{'status'} eq RESOLVING   }
+sub is_rejecting   { (shift)->{'status'} eq REJECTING   }
+sub is_resolved    { (shift)->{'status'} eq RESOLVED    }
+sub is_rejected    { (shift)->{'status'} eq REJECTED    }
+
+# the three possible states according to the spec ...
+sub is_unfulfilled { (shift)->is_in_progress            }
+sub is_fulfilled   { $_[0]->is_resolved || $_[0]->is_resolving }
+sub is_failed      { $_[0]->is_rejected || $_[0]->is_rejecting }
+
 sub resolve {
     my $self   = shift;
     my $result = [ @_ ];
@@ -66,7 +78,13 @@ sub then {
         || confess "You must pass in a success callback";
 
     (ref $error && reftype $error eq 'CODE')
-        || confess "You must pass in a error callback";
+        || confess "You must pass in a error callback"
+            if $error;
+
+    # if we don't get an error
+    # handler, we need to chain
+    # it automatically
+    $error ||= sub { @_ };
 
     my $d = (ref $self)->new;
 
@@ -91,7 +109,7 @@ sub _wrap {
         if ( (scalar @results) == 1 && blessed $results[0] && $results[0]->isa('Promises::Promise') ) {
             $results[0]->then(
                 sub { $d->resolve( @{ $results[0]->result } ) },
-                sub { $d->reject  },
+                sub { $d->reject( @{ $results[0]->result } )  },
             );
         }
         else {
@@ -117,7 +135,7 @@ Promises::Deferred - An implementation of Promises in Perl
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 SYNOPSIS
 
@@ -173,17 +191,26 @@ the C<resolve> or C<reject> methods. It will always return
 an ARRAY reference since both C<resolve> and C<reject>
 take a variable number of arguments.
 
-=item C<then( $callback, $error )>
+=item C<then( $callback, ?$error )>
 
 This method is used to register two callbacks, the first
 C<$callback> will be called on success and it will be
 passed all the values that were sent to the corresponding
-call to C<resolve>. The second, C<$error> will be called
-on error, and will be passed the all the values that were
-sent to the corresponding C<reject>. It should be noted
-that this method will always return the associated
-L<Promises::Promise> instance so that you can chain
-things if you like.
+call to C<resolve>. The second, C<$error> is optional and
+will be called on error, and will be passed the all the
+values that were sent to the corresponding C<reject>.
+It should be noted that this method will always return
+the associated L<Promises::Promise> instance so that you
+can chain things if you like.
+
+If this is the last link in the chain, and there is no
+C<$error> callback, the error be silent. You can still
+find it by checking the C<result> method, but no action
+will be taken. If this is not the last link in the chain,
+and no C<$error> is specified, we will attempt to bubble
+the error to the next link in the chain. This allows
+error handling to be consolidated at the point in the
+chain where it makes the most sense.
 
 =item C<resolve( @args )>
 
@@ -205,6 +232,48 @@ of arguments and captures them as the C<result> of this
 promise (so obviously they can be retrieved with the
 C<result> method).
 
+=item C<is_in_progress>
+
+This is a predicte method against the status value, it
+returns true of the status is C<IN_PROGRESS>.
+
+=item C<is_resolving>
+
+This is a predicte method against the status value, it
+returns true of the status is C<RESOLVING>.
+
+=item C<is_rejecting>
+
+This is a predicte method against the status value, it
+returns true of the status is C<REJECTING>.
+
+=item C<is_resolved>
+
+This is a predicte method against the status value, it
+returns true of the status is C<RESOLVED>.
+
+=item C<is_rejected>
+
+This is a predicte method against the status value, it
+returns true of the status is C<REJECTED>.
+
+=item C<is_unfulfilled>
+
+This is a predicte method against the status value, it
+returns true of the status is still C<IN_PROGRESS>.
+
+=item C<is_fulfilled>
+
+This is a predicte method against the status value, it
+returns true of the status is C<RESOLVED> or if the
+status if C<RESOLVING>.
+
+=item C<is_failed>
+
+This is a predicte method against the status value, it
+returns true of the status is C<REJECTED> or if the
+status if C<REJECTING>.
+
 =back
 
 =head1 AUTHOR
