@@ -3,7 +3,7 @@ BEGIN {
   $Promises::Promise::AUTHORITY = 'cpan:STEVAN';
 }
 {
-  $Promises::Promise::VERSION = '0.01';
+  $Promises::Promise::VERSION = '0.02';
 }
 # ABSTRACT: An implementation of Promises in Perl
 
@@ -24,6 +24,16 @@ sub then    { (shift)->{'deferred'}->then( @_ ) }
 sub status  { (shift)->{'deferred'}->status     }
 sub result  { (shift)->{'deferred'}->result     }
 
+sub is_unfulfilled { (shift)->{'deferred'}->is_unfulfilled }
+sub is_fulfilled   { (shift)->{'deferred'}->is_fulfilled   }
+sub is_failed      { (shift)->{'deferred'}->is_failed      }
+
+sub is_in_progress { (shift)->{'deferred'}->is_in_progress }
+sub is_resolving   { (shift)->{'deferred'}->is_resolving   }
+sub is_rejecting   { (shift)->{'deferred'}->is_rejecting   }
+sub is_resolved    { (shift)->{'deferred'}->is_resolved    }
+sub is_rejected    { (shift)->{'deferred'}->is_rejected    }
+
 1;
 
 __END__
@@ -36,7 +46,7 @@ Promises::Promise - An implementation of Promises in Perl
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 DESCRIPTION
 
@@ -75,6 +85,38 @@ This calls C<status> on the proxied L<Promises::Deferred> instance.
 
 This calls C<result> on the proxied L<Promises::Deferred> instance.
 
+=item C<is_unfulfilled>
+
+This calls C<is_unfulfilled> on the proxied L<Promises::Deferred> instance.
+
+=item C<is_fulfilled>
+
+This calls C<is_fulfilled> on the proxied L<Promises::Deferred> instance.
+
+=item C<is_failed>
+
+This calls C<is_failed> on the proxied L<Promises::Deferred> instance.
+
+=item C<is_in_progress>
+
+This calls C<is_in_progress> on the proxied L<Promises::Deferred> instance.
+
+=item C<is_resolving>
+
+This calls C<is_resolving> on the proxied L<Promises::Deferred> instance.
+
+=item C<is_rejecting>
+
+This calls C<is_rejecting> on the proxied L<Promises::Deferred> instance.
+
+=item C<is_resolved>
+
+This calls C<is_resolved> on the proxied L<Promises::Deferred> instance.
+
+=item C<is_rejected>
+
+This calls C<is_rejected> on the proxied L<Promises::Deferred> instance.
+
 =back
 
 =head1 AUTHOR
